@@ -32,7 +32,7 @@ use vars qw(
 require Exporter;
 @ISA = qw(Exporter);
 
-$VERSION = do { my @r = (q$Revision: 0.10 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 0.11 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 @EXPORT_OK = qw(
         run
@@ -92,6 +92,10 @@ The sample configuration file
 B<monitor.conf.sample> is heavily commented with the details for each
 configuration element.
 
+A useful list of DNSBL zones for the config file (put together by 
+"Andrey V. Stolyarov" <croco-gnu@openwall.com>)
+maybe found in the B<contrib> directory C<zones4config.file>.
+
 =head1 SYSTEM SIGNALS
 
 B<dnsblmon> responds to the following system signals:
@@ -175,7 +179,7 @@ The -r and -s switchs are position dependent output designators.
 
   -r -s would produce the report on STDOUT and the statistics
 	on STDERR.
-  -s -r would produce the statistics on STOUT and the 
+  -s -r would produce the statistics on STDOUT and the 
 	report on STDERR.
 
   -s outfile1 -r outfile2 would write the statistics and report
@@ -452,12 +456,7 @@ LOOP:
 	  foreach(0..$ancount-1) {
 	    ($off,$name,$t,$class,$ttl,$rdl,@rdata) = $get->next(\$msg,$off);
 	    if ($t == T_A) {
-	      if (exists $conf->{"$bl"}->{acceptany}) {
-		$ip = inet_ntoa($rdata[0]);
-		onion(\%dnsbls,\%ips,$revIP,$now + $uto,\%ipin,$bl,\%respons,$ip);
-		next LOOP;
-	      }
-	      while($answer = shift @rdata) {
+	      foreach $answer (@rdata) {
 		$ip = inet_ntoa($answer);
 		if (grep($ip eq $_,keys %{$conf->{"$bl"}->{accept}})) {
 		  onion(\%dnsbls,\%ips,$revIP,$now + $uto,\%ipin,$bl,\%respons,$ip);
@@ -465,6 +464,11 @@ LOOP:
 		  next LOOP;
 		}
 	      }
+	      if (exists $conf->{"$bl"}->{acceptany}) {
+		$ip = inet_ntoa($rdata[0]);
+		onion(\%dnsbls,\%ips,$revIP,$now + $uto,\%ipin,$bl,\%respons,$ip);
+		next LOOP;
+	      }
 	    }
 	    elsif ($needPTR && $t == T_PTR && exists $dnsbls{GENERIC}) {
 # positive in-addr.arpa responses are ignored
